@@ -28,7 +28,7 @@ boxqq = function(formula, ...) {
 #' @export
 boxqq.formula = function(formula, data = NULL, ...) { 
 
-  oldPar = par()
+  oldPar = par(no.readonly = TRUE)
   
   if (missing(formula) || (length(formula) != 3)) 
     stop("'formula' missing or incorrect")
@@ -74,6 +74,6 @@ boxqq.formula = function(formula, data = NULL, ...) {
     abline(mean(data[data[, 2] == names[j], 1]), sd(data[data[, 2] == names[j], 1]), col = j)
   }
   
-  par(oldPar)
+  par(oldPar, no.readonly = TRUE)
 }
 
